FUNCTION cross_prod_sgl ( v1, v2 )
!
!  Purpose:
!    To calculate the cross product of two three-dimensional
!    vectors.
!
!  Record of revisions:
!      Date       Programmer          Description of change
!      ====       ==========          =====================
!    06/21/96    S. J. Chapman        Original code
!
IMPLICIT NONE

! Declare local parameters
INTEGER, PARAMETER :: kind = SELECTED_REAL_KIND(p=6) ! Precision

! Declare calling arguments.
REAL(KIND=kind), DIMENSION(3), INTENT(IN) :: v1  ! First input vector.
REAL(KIND=kind), DIMENSION(3), INTENT(IN) :: v2  ! Second input vector.
REAL(KIND=kind), DIMENSION(3) :: cross_prod 

! Calculate the cross product of the two vectors.
cross_prod(1) = v1(2) * v2(3) - v2(2) * v1(3)
cross_prod(2) = v1(3) * v2(1) - v2(3) * v1(1)
cross_prod(3) = v1(1) * v2(2) - v2(1) * v1(2)

END FUNCTION cross_prod_sgl

FUNCTION cross_prod_dbl ( v1, v2 )
!
!  Purpose:
!    To calculate the cross product of two three-dimensional
!    vectors.
!
!  Record of revisions:
!      Date       Programmer          Description of change
!      ====       ==========          =====================
!    06/21/96    S. J. Chapman        Original code
!
IMPLICIT NONE

! Declare local parameters
INTEGER, PARAMETER :: kind = SELECTED_REAL_KIND(p=12) ! Precision

! Declare calling arguments.
REAL(KIND=kind), DIMENSION(3), INTENT(IN) :: v1  ! First input vector.
REAL(KIND=kind), DIMENSION(3), INTENT(IN) :: v2  ! Second input vector.
REAL(KIND=kind), DIMENSION(3) :: cross_prod 

! Calculate the cross product of the two vectors.
cross_prod(1) = v1(2) * v2(3) - v2(2) * v1(3)
cross_prod(2) = v1(3) * v2(1) - v2(3) * v1(1)
cross_prod(3) = v1(1) * v2(2) - v2(1) * v1(2)

END FUNCTION cross_prod_dbl
